# -*- coding: utf-8 -*-
"""
Created on Sun Jan 19 18:18:01 2020

@author: eternal_demon
"""

import numpy as np
import pandas as pd
import math

class topsis:
    
    def __init__(self,filename):
        data = pd.read_csv(filename)
        self.d = data.iloc[:,1:].values #Chnage according to which row or column you want to exclude
        self.d = self.d.astype("float64")
        self.features=len(self .d[0])
        self.samples=len(self.d)

    def evaluate(self,weights,impacts):
        data=self.d
        rows=self.samples
        cols=self.features
        if (weights==None):
            weights=[1]*weights
        if (impacts==None):
            impacts=["+"]*impacts
        
        
        #Finding the value with which each column's value will be divided
        divisor=[]
        for i in range(cols):
            temp=0
            for j in range(rows):
                temp = temp + (data[j,i]*data[j,i])
            temp = math.sqrt(temp)
            divisor.append(temp)
                
        #Divinding
        for i in range(rows):
            for j in range(cols):
                data[i,j]=data[i,j]/divisor[j]
                
        #Normalized Matrix
        for i in range(cols):
            for j in range(rows):
                data[j,i]=data[j,i]*float(weights[i])
                
        #Calculation of ideals
        ideal_best=[]
        ideal_worst=[]
        
        maximum_val = np.amax(data, axis=0)
        minimum_val = np.amin(data, axis=0)
        for i in range(cols):
            if impacts[i] == '+':
                ideal_best.append(maximum_val[i])
                ideal_worst.append(minimum_val[i])
            elif impacts[i] == '-':
                ideal_best.append(minimum_val[i])
                ideal_worst.append(maximum_val[i])
                
        #Calculation Euclidean distance both i,e. worst and ideal
        
        distbest = []
        for i in range(rows):
            sum1 = 0
            for j in range(cols):
                sum1 = sum1 + ((data[i][j] - ideal_best[j]) ** 2)
            temp1 = sum1 ** 0.5
            distbest.append(temp1)
        
        distworst = []
        for i in range(rows):
            sum2 = 0
            for j in range(cols):
                sum2 = sum2 + ((data[i][j] - ideal_worst[j]) ** 2)
            temp2 = sum2 ** 0.5
            distworst.append(temp2)
            
        #Calculating Perforance or P's
        p=[]
        
        for i in  range(rows):
            temp=distworst[i]/(distworst[i]+distbest[i])
            p.append(temp)
            
        #Assigning Ranks and choosing the best
        return p


import topsis_new as tp
import pandas as pd
import numpy as np
dataset= tp.topsis("data.csv")

weights=[1,2,1,1]
impacts=["+","+","-","+"]
result =tp.topsis.evaluate(dataset,weights,impacts)
x = result
seq = sorted(x)
index = [seq.index(v)+1 for v in x]

print(index)



# -*- coding: utf-8 -*-
"""
Created on Sun Jan 19 19:49:25 2020

@author: eternal_demon
"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="topsis_bhanu", # Replace with your own username
    version="0.0.2",
    author="Bhanu/eternal_demon",
    author_email="aggarwal.bhanu02@gmail.com",
    description="Implementation of topsis over a csv datafile using the distance calculation and comparison approach",
    long_description="",
    long_description_content_type="text/markdown",
    url="https://github.com/eternaldemon/topsis_bhanu",
    download_url="https://github.com/eternaldemon/topsis_bhanu/archive/0.0.2.tar.gz",
    packages=["topsis_bhanu"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)